#
# spec file for package gpsd
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define		libgps libgps22
%define		libQgps libQgpsmm22
%define         _udevdir %(pkg-config --variable udevdir udev)
Name:           gpsd
Version:        3.15
Release:        1.13
Summary:        Service daemon for mediating access to a GPS
License:        BSD-3-Clause
Group:          Hardware/Other
Url:            http://www.catb.org/gpsd/
Source0:        http://download-mirror.savannah.gnu.org/releases/gpsd/%{name}-%{version}.tar.gz
Source98:       http://download-mirror.savannah.gnu.org/releases/gpsd/%{name}-%{version}.tar.gz.sig
Source1:        rules.gpsd
Source2:        udev.gpsd
Source3:        sysconfig.gpsd
Source4:        gpsd.xpm
Source5:        xgps.desktop
Source6:        xgpsspeed.desktop
Source99:       %{name}.keyring
Patch0:         gpsd-fix-shebang.patch
BuildRequires:  bluez-devel
BuildRequires:  chrpath
BuildRequires:  dbus-1-glib-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libcap-devel
BuildRequires:  libqt4-devel >= 4.5.3
BuildRequires:  libusb-1_0-devel
BuildRequires:  ncurses-devel
BuildRequires:  pps-tools-devel
BuildRequires:  python-devel
BuildRequires:  scons >= 2.0.1
BuildRequires:  update-desktop-files
BuildRequires:  xmlto
BuildRequires:  pkgconfig(udev)
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd-rpm-macros
%systemd_requires
%endif
Requires:       udev
Requires(pre):  %fillup_prereq
Requires(pre):  coreutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
gpsd is a service daemon that mediates access to a GPS sensor connected
to the host computer by serial or USB interface, making its data on the
location/course/velocity of the sensor available to be queried on TCP
port 2947 of the host computer.  With gpsd, multiple GPS client
applications (such as navigational and wardriving software) can share
access to a GPS without contention or loss of data.  Also, gpsd
responds to queries with a format that is substantially easier to parse
than NMEA 0183.  A client library is provided for applications.

After installing this RPM, gpsd will automatically connect to USB GPSes
when they are plugged in and requires no configuration.  For serial
GPSes, you will need to start gpsd by hand.  Once connected, the daemon
automatically discovers the correct baudrate, stop bits, and protocol.
The daemon will be quiescent when there are no clients asking for
location information, and copes gracefully when the GPS is unplugged
and replugged.

%package devel
Summary:        Client libraries in C and Python for talking to a running gpsd or GPS
Group:          Development/Libraries/C and C++
Requires:       %{libQgps}
Requires:       %{libgps}
Requires:       %{name} = %{version}
Requires:       pkgconfig
Requires:       python-curses
Requires:       python-gpsd = %{version}

%description devel
This package provides C header files for the gpsd shared libraries that
manage access to a GPS for applications and debugging tools. You will
need to have gpsd installed for it to work.

%package -n %{libgps}
Summary:        Shared library for GPS applications
Group:          Development/Libraries/Python

%description -n %{libgps}
This package provides the shared library for gpsd and other GPS aware
applications.

%package -n %{libQgps}
Summary:        Shared Qt library for GPS applications
Group:          Development/Libraries/Python

%description -n %{libQgps}
This package provides the shared Qt library for gpsd and other GPS aware
applications.

%package -n python-gpsd
Summary:        Client libraries in C and Python for talking to a running gpsd or GPS
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
%py_requires

%description -n python-gpsd
This package provides python modules and tools for the gpsd shared libraries.
You will need to have gpsd installed for it to work.

%package clients
Summary:        Clients for gpsd with an X interface
Group:          Hardware/Other
Requires:       python-gpsd
Requires:       python-gtk

%description clients
xgps is a simple test client for gpsd with an X interface. It displays
current GPS position/time/velocity information and (for GPSes that
support the feature) the locations of accessible satellites.

xgpsspeed is a speedometer that uses position information from the GPS.
It accepts an -h option and optional argument as for gps, or a -v
option to dump the package version and exit. Additionally, it accepts
-rv (reverse video) and -nc (needle color) options.

cgps resembles xgps, but without the pictorial satellite display.  It
can run on a serial terminal or terminal emulator.

%prep
%setup -q
%patch0 -p1

# don't set RPATH
sed -i 's|env.Prepend.*RPATH.*|pass #\0|' SConstruct

%build
export CFLAGS="%{optflags} -fvisibility-inlines-hidden"
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
scons prefix=%{_prefix} libdir=%{_libdir} strip=False

%install
export CFLAGS="%{optflags} -fvisibility-inlines-hidden"
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
DESTDIR=%{buildroot} scons prefix=%{_prefix} libdir=%{_libdir} strip=False install
install -d -m 755 %{buildroot}%{_udevdir}
install -d -m 755 %{buildroot}%{_udevdir}/rules.d
install -d -m 755 %{buildroot}%{_localstatedir}/adm/fillup-templates
install -d -m 755 %{buildroot}%{_datadir}/{applications,pixmaps}
install -m 644 %{SOURCE1} %{buildroot}%{_udevdir}/rules.d/51-gpsd.rules
install -m 755 %{SOURCE2} %{buildroot}%{_udevdir}/gpsd.sh
install -m 644 %{SOURCE3} %{buildroot}%{_localstatedir}/adm/fillup-templates
if [ -f %{buildroot}%{python_sitearch}/*.egg-info ] ; then
  rm -f %{buildroot}%{python_sitearch}/*.egg-info
fi
chmod 755 %{buildroot}%{python_sitearch}/gps/gps.py
# install desktop entries
install -m 644 %{SOURCE4} %{buildroot}%{_datadir}/pixmaps/%{name}.xpm
install -m 644 %{SOURCE5} %{buildroot}%{_datadir}/applications/
install -m 644 %{SOURCE6} %{buildroot}%{_datadir}/applications/
%if 0%{?suse_version} >= 1210
install -D -m 644 systemd/gpsd.service %{buildroot}/%{_unitdir}/gpsd.service
install -D -m 644 systemd/gpsd.socket %{buildroot}/%{_unitdir}/gpsd.socket
install -D -m 644 systemd/gpsdctl@.service %{buildroot}/%{_unitdir}/gpsdctl@.service
ln -s  	%{_sbindir}/service %{buildroot}%{_sbindir}/rcgpsd
%endif

%suse_update_desktop_file xgpsspeed
%suse_update_desktop_file xgps
# save some space, create symlinks
%fdupes -s %{buildroot}

%pre
%if 0%{?suse_version} >= 1210
%service_add_pre gpsd.service gpsdctl@.service
%endif

%post
/sbin/ldconfig
%fillup_only -n gpsd
%if 0%{?suse_version} >= 1210
%service_add_post gpsd.service gpsdctl@.service
%udev_rules_update
%endif

%preun
%if 0%{?suse_version} >= 1210
%service_del_preun gpsd.service gpsdctl@.service
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} >= 1210
%service_del_postun gpsd.service gpsdctl@.service
%endif

%post -n %{libgps} -p /sbin/ldconfig

%postun -n %{libgps} -p /sbin/ldconfig

%post -n %{libQgps} -p /sbin/ldconfig

%postun -n %{libQgps} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING gpsd.php
%{_mandir}/man?/gpsd.*
%{_mandir}/man?/gpsdctl.*
%{_mandir}/man?/gpsctl.*
%{_mandir}/man?/gpsinit.*
%{_udevdir}/gpsd.sh
%{_udevdir}/rules.d/*
%if 0%{?suse_version} >= 1210
%{_unitdir}/gpsd.service
%{_unitdir}/gpsd.socket
%{_unitdir}/gpsdctl@.service
%{_sbindir}/rcgpsd
%endif
%{_sbindir}/gpsd
%{_sbindir}/gpsdctl
%{_bindir}/gpsctl
%{_localstatedir}/adm/fillup-templates/sysconfig.gpsd

%files -n %{libgps}
%defattr(-,root,root)
%{_libdir}/libgps.so.*

%files -n %{libQgps}
%defattr(-,root,root)
%{_libdir}/libQgpsmm.so.*

%files devel
%defattr(-,root,root)
%doc README COPYING TODO
%{_mandir}/man?/gpsfake.*
%{_mandir}/man?/gpscat.*
%{_mandir}/man?/libQgps*.*
%{_mandir}/man?/libgps*.*
%{_mandir}/man?/srec.*
%{_mandir}/man?/gpsdecode.*
%{_mandir}/man?/gpsd_json.*
%{_mandir}/man?/gpsprof.*
%{_bindir}/gpsfake
%{_bindir}/gpscat
%{_bindir}/gpsdecode
%{_bindir}/gpsprof
%{_includedir}/gps.h
%{_includedir}/libgpsmm.h
%{_libdir}/libgps.so
%{_libdir}/libQgpsmm.so
%{_libdir}/libQgpsmm.prl
%{_libdir}/pkgconfig/libgps*.pc
%{_libdir}/pkgconfig/Qgpsmm.pc

%files -n python-gpsd
%defattr(-,root,root)
%{python_sitearch}/gps/

%files clients
%defattr(-,root,root)
%{_mandir}/man?/gps.*
%{_mandir}/man?/gegps.*
%{_mandir}/man?/cgps.*
%{_mandir}/man?/lcdgps.1.gz
%{_mandir}/man?/xgps.*
%{_mandir}/man?/xgpsspeed.*
%{_mandir}/man?/gpspipe.*
%{_mandir}/man?/gpsmon.*
%{_mandir}/man?/gps2udp.*
%{_mandir}/man?/ntpshmmon.*
%{_bindir}/gegps
%{_bindir}/xgps
%{_bindir}/xgpsspeed
%{_bindir}/cgps
%{_bindir}/lcdgps
%{_bindir}/gpsmon
%{_bindir}/gpspipe
%{_bindir}/gps2udp
%{_bindir}/gpxlogger
%{_bindir}/ntpshmmon
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.xpm

%changelog
* Tue Aug  9 2016 lnussel@suse.de
- use pkgconfig(udev) to always allow using udev-mini
* Mon Aug  8 2016 benoit.monin@gmx.fr
- add pps-tools-devel as BuildRequires to enable kernel PPS
* Mon Aug  1 2016 lnussel@suse.de
- use pkg-config to figure out udevdir. Fixes bootstrapping with
  udev-mini
* Tue Nov 24 2015 joop.boonen@opensuse.org
- Added missing requirements %%{libgps} and %%{libQgps} for devel package
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 3.15
  * Fix a rare crash bug related to devices becomin inaccessible
    while timed out.
  * Accept NMEA 4.1 GSV sententences with the trailing signal-ID field.
  * Fixed incorrect decode of south latitudes in AIS Type 17 messages.
  * splint has been retired; this removes almost 2KLOC of annotations.
  * chrpath is no longer a build dependency. Corrected Beidou/QZNSS display
    in the Python clients so the graphics don't look like SBAS.
- Changes from version 3.14
  * Skyview support for the Beidou and QZSS constellations in the
    NMEA0183 driver.
  * ntpmon rename to ntpshmmon - it doesn't actually monitor NTP itself.
  * New HOWTO on the website: "Introduction to Time Service".
- Remove gpsd-3.13-ntpshm.patch; fixed on upstream release
* Sat Mar  7 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
- Add gpsd-3.13-ntpshm.patch
- Install unit files
- Update to 3.13
  * compiler.h inclusion removed for gps.h so it's standalone
    for /usr/include.
  * TOFF JSON report gives the offset between GPS top of second and
    clock time.
  * A new ntpmon tool supports capturing clock samples from NTP
    SHM segments.
- Changes for 3.12
  * The daemon's power utilization has been reduced by changing
    from non-blocking to blocking I/O; this may be significant
    on mobile devices.
  * Better protection against false matches of Inland AIS messages;
    thisrequired a libgps version bump to 22 (as a side effect,
    per-devicefootprint has decreased).
  * PPS feature is no longer markedexperimental/unstable.
  * Sentence tag fields have been dropped from the JSON reports.
  * GNSS and GLONASS SKY reports are now merged.
  * Addressed versions of AIS Type 25 and 26 are now handled.
  * The 'nmea' build option is now 'nmea0183'.
  * New 'minimal' option sets all boolean options not explicitly
    set on the build command line to false.
  * The 'limited_max_devices' option is now 'max_devices'; the
    'limited_max_clients' option is now 'max_clients'
  * The previously deprecated 'libQgpsmm' option has been
    removed; use 'qt'.
  * A bug fix for error modeling when NMEA 0183 reports empty DOP fields.
  * On OS X, the "osx-pl203" driver has been explicitly listed
    as unsupported.
  * The last remnants of the old pre-JSON query protocol have
    been removed from the client library.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 3.11
  * A bug that prevented track interpolation has been fixed.
  * We now get vertical error position and speed estimates from the
    u-blox driver rather than having to interpolate them.
  * Some unusual AIS talker IDs (NMEA 4.0 station classes) are supported.
  * chrpath is no longer a dependency for building and testing, and
    now defaults to 'no'.
  * Full systemd support.
  * Fixes for handling large PPS offsets.
  * Improved recovery from device flakeouts, gpsmon argument parsing.
- Disable chrpath
* Tue Nov 25 2014 dl8fcl@darc.de
- Added python-gpsd requires for gpsd-clients
* Mon Oct  6 2014 crrodriguez@opensuse.org
- Respect CFLAGS and CXXFLAGS.
- Use fvisibility-inlines-hidden to build C++ code, note
  that the build system is buggy and uses CFLAGS and CXXFLAGS
  for the same purpose.
- Remove xorg libs buildrequires, they are never directly used.
* Mon Dec  9 2013 opensuse@dstoecker.de
- update to version 3.10
  AIS: Adds gps2udp, an AIS data relay, split24 option supports
  passing through Type 24 halves; support for Inland AIS; "scaled" no
  longer controls dumping of controlled-vocabulary fields; instead,
  the're always dumped numerically and as text, with text in an
  attribute name generated by appending "_text" to the name of the
  base attribute. The packetizer's handling of write boundaries not
  coinciding with packet boundaries is improved.  Better support for
  mode and speed switching in the UBX driver.  PPS message now ships
  nsec. PPS events are visible in gpsmon. Time-reporting fix to TSIP.
* Wed Nov 20 2013 suse@bugs.jan.ritzerfeld.org
- Fixed typo in udev rule (bnc#848936)
* Mon Oct 28 2013 p.drouand@gmail.com
- Update to version 3.9
  + Note to packagers: this is an urgent release that fixes a possible
    DoS or security hole!  Armor the AIS driver against an implausible
    overrun attack.  A (different) fix for our first malformed-packet
    crash since about 2007. Minor improvements to the NMEA2000
    driver. New FAQ entry on how to know WAAS/EGNOS is working.
  + New -u and -uu options enable usec timestamps on gpspipe output.
  For more please read usr/share/doc/packages/gpsd/NEWS
- Clean specfile and remove AUTHORS section
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build and adapt udev rule to new udev location.
* Mon Apr 23 2012 opensuse@dstoecker.de
- update to gpsd version 3.5
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Oct 15 2011 andrea.turrini@gmail.com
- fixed typos in gpsd.spec
* Sat May 14 2011 dmueller@suse.de
- move libgpsd.so.0 from the shlib subpackage to the main package,
  as it fileconflicts with other versions of it. the library is
  internal only anyway.
* Sat Apr 30 2011 jw@novell.com
- gpsd-devel depends on python-gpsd too.
* Mon Apr  4 2011 devel@navlost.eu
- Update to version 2.96:
  + Bumped maximum channel count to 32 to accommodate GPS+GLONASS devices.
  + API version bumped to 5, redesign finished (changes are documented
    in the Client HOWTO).
  + cgps now handles resize signals.
  + Code can now link with uClibc for embedded use.
  + Various bugs in the C++ binding have been fixed.
  + gpxlogger can now daemonize and write to a specified log file.
  + A gpsd client can now set any locale it likes, and JSON
    will still be parsed using the C locale matching the daemon's.
  + Clients are no longer required to define a gpsd_report() hook.
  + gpsd no longer emits probe strings to unidentified USB devices at startup.
  + JSON timestamps in TPV and SKY are now ISO8601 rather than seconds since
    the Unix epoch; the library handles the older style backward-compatibly.
  + GPGST sentences are now parsed for noise statistics when a device emits
    them.
  + AIS and RTCM2 JSON dumps have device fields.
  + JSON reports now include 50bps subframe data if the device allows access to
    it.
  + gpsdecode can now dump NMEA GPS binary, and subframe data to JSON.
  + The RTCM2 code now understands and  analyzes RTCM2.3 messages 13,
    14, and 31, and has been checked against another analyzer.
  + The ancient Sager dump format for RTCM2 is abolished in favor of a JSON
    profile.
* Tue Oct 26 2010 jreuter@novell.com
- Move udev rules from /etc/udev/rules.d to /lib/udev/rules.d
- Update to version 2.95:
  + Rationalize clearing and generation of DOPs
  + cgps now displays epx/epy rather than eph
  + Speed is now always reported if our last two fixes were good
  + Reading packets from UDP datagrams by specifying a listening
    address and port is now supported
  + AIS code now interprets message type 6 and 8 application IDs
    correctly as a Designated Area Code and Functional ID pair
  + gpspipe has a new -T option for setting the timestamp format
  + xgpsspeed is completely rewritten in Python
  + Qt bindings for the client library
  + gpsdcode now uses | as a field separator in -c mode, as string
    fields can contain commas
  + Corrected error for reporting of AIS rate-of-turn fields
- Changes of version 2.94:
  + Error-checking in the 50bps subframe code has been greatly
    improved
  + The Garmin GPS driver can now use libusb for device discovery
  + The libgps library has been split apart; the service functions
    used by the daemon now live in libgpsd
  + Stronger checking for valid ephemeris before extracting the
    leap-second offset
- Changes of version 2.93:
  + Support for JSON dumping and parsing of AIS message types 25 and 26
  + Removing non-streaming mode from the Python exerciser
  + Unsetting the appropriate in-use flag in the device array
  + Change the libgps default from old protocol to JSON
  + Add a close() method to the C++ binding
  + Try to recover better from sporadic cases of false matches to
    Trimble packet format from a SiRF binary datastream
  + gps_poll() now returns -1 with errno not set when the gpsd
    socket closes
  + TPV now refrains from reporting fields the fix quality won't support
  + gpsmon option for listing device types is now -L to -l can be used
    to enable logging
  + Documentation updates
  + New POLL command brings back polling-mode operation
  + gpsd no longer eats CPU when a device is unexpectedly uplugged
  + Support for the TNT revolution is back (run mode only)
  + There is now a gpsdfake diagnostic tool that fakes being gpsd shipping
    arbitrary specified data to clients.
* Sat Mar 27 2010 vuntz@opensuse.org
- Update to version 2.92:
  + Fix a packaging error: the python library module was omitted
    from the 2.91 tarball.
  + Improve the json import test.
- Changes from version 2.91:
  + We have support for NMEA GLONASS sentences, and a regression
    test.
  + Clients now get a DEVICE notification on every driver switch.
  + It is possible to specify a TCP/IP AIS feed such as AISHub as a
    data source.
  + Serious bitrot in the NTRIP support has been fixed - it was
    probably nonfunctional for several releases before this.
  + Fixed buggy display of satellite-used flags in cgps.
  + xgps is replaced by a rewrite in Python that uses pygtk,
    eliminating a dependency on Motif; also, it now displays AIS
    information.
  + Uniform treatment of display-unit defaulting and -u in xgps,
    cgps, and lcdgps.
  + Support for AIS message types 25 and 26.
  + Support for IPv6.
  + A numeric instability in the earth_distance() function
    affecting track error modeling has been fixed.
  + Old protocol has been removed from the daemon; the library
    still speaks it.
- Drop openmotif, openmotif-devel BuildRequires.
- Add xorg-x11-devel, xorg-x11-libXpm-devel BuildRequires.
- Add gpsd-fix-python-install.patch to fix installation of the
  python bindings.
- Add python-gtk Requires to gpsd-clients subpackage as xgps now
  depends on it.
- Use a valid group for the devel subpackage.
- Do not manually strip executables: this will be done by the build
  service.
* Fri Feb 12 2010 jreuter@novell.com
- Add missing dependency to python-curses for devel package (bnc#574584)
- Add another Cyprus GPS USB id (bnc#574584)
* Fri Dec 18 2009 seife@opensuse.org
- fix udev warnings "SYSFS is deprecated"
* Tue Dec  8 2009 jreuter@novell.com
- Fix libgps subpackage requirements
* Tue Dec  8 2009 jreuter@novell.com
- Upgrade to gpsd-2.90, from the upstream change log:
  - GPSD-NG, the new JSON-based command protocol, is now deployed
  - Detection of end of a fix-reporting cycle is now reliable
  - Abandone gpsflash subproject
  - Increase major version of shared library due to significant API change
  - Add new driver for Motorola Oncore receivers
  - gpsfake can now accept multiple logfiles, interleaving test sentences
    from each.
  - gpsd now accepts error estimates from the NMEA $GPGBS sentence.
  - Fix potential core dump in C client handling of "K" responses
  - Introduce major and minor API version symbols into the public interfaces
  - The sirfmon utility is gone, replaced by gpsmon
  - Fix an old error in NMEA parsing
  - cgpxlogger has been merged into gpxlogger.
  - Speed-setting commands now allow parity and stop-bit setting
  - tcmdecode becomes gpsdecode and can now de-armor and dump AIDVM packets
  - The clientlibrary now works correctly in locales where the decimal
    separator is not a period.
- Typo in sirfmon / gpsmon has been fixed silently by upstream (#bnc513037)
- Make libgps and python modules subpackages
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Mon Nov 24 2008 jreuter@suse.de
- Disable TrueNorth Technologies device support, it breaks
  autodection (bnc#448002)
- Fix udev script again: must not kill running gpsd if disabled,
  missing quotes in test, indention, add parameter to set additional
  command line options for gpsd.
* Wed Nov 19 2008 jreuter@suse.de
- Sleep a second before setting the default device in udev
  script to give gpsd some time to set up the TCP socket
* Thu Oct 23 2008 jreuter@suse.de
- Disable start of gpsd by udev rule by default and add sysconfig
  variable to enable it if desired (bnc#432420)
* Thu Apr 24 2008 jreuter@suse.de
- Fix RPM group tag for devel package
- Cleanup spec file
* Sat Mar 22 2008 lrupp@suse.de
- update to 2.37
  Fixes:
  + C++ bindings
  + Garmin USB support
  + multiple instances of ntp pps thread starting
  + better handling of odd PPS signals
  + eye candy in the php visualizers
- enable Garmin Simple Text support
- enable True North Technologies support
- disable static
- mark man files as %%doc
- added desktop entries
- fix ldconfig calls
- clean buildroot
- PreReq coreutils and fillup_prereq for postinstall
* Fri Jan 18 2008 jreuter@suse.de
- updated to 2.36
  * Integrated Garmin Simple Text Protocol driver from Peter Slansky.
  * Stabilize the Trimble regression tests.
  * Remove the wired-in NTP time offset from the NMEA driver
  * Integrate Ashtech driver from Chris Kuethe.
- Submit to STABLE for 11.0
* Thu Dec 13 2007 opensuse@dstoecker.de
- updated to 2.35
* Tue Nov 20 2007 anschneider@suse.de
- update udev rules and script
* Fri Jun 29 2007 anschneider@suse.de
- Spec file cleanup
* Sun Dec 17 2006 anschneider@suse.de
- update to version 2.34:
  * Fix for byte-swapping of Zodiac control messages on big-endian hardware.
  * Disable iTalk by default and note that it needs to be tested.
  * Command line arguments can now be DGPSIP or NTRIP URLs; -d is
    deprecated.
  * Added udev rules.
  * Address excessive processor and memory utilization on SBCs; it's now
    possible to configure compile-time limits on the number of devices and
    client sessions.
  * Eliminate use of fuser(1) in gpsfake.
  * Get gpsd working with EarthMates again, this had been broken since 2.15.
    Massive string safety audit and OpenBSD port by Chris Kuethe.
  * J command added.
  * The gpsctl and gpscat tools and the gpsd.phps script were added.
  * Switched to lesstif from openmotif.
  * Better autodetection of DLE-led packet protocols (notably TSIP and Garmin
    binary) and of SiRFStar I and III devices.
  * Fixed buggy parsing and generation of PGRME.
* Mon Jun  5 2006 anschneider@suse.de
- Initial package
